@@ -73,7 +73,7 @@ class NodeExtender(AssignationUIMixin, BaseExtender):
 
     def stream(self, inputs: dict, params: AssignationParams = None, **kwargs):
 
-        return stream.iterate(self._postman.stream(self, inputs, params, **kwargs)).stream()
+        return stream.iterate(self._postman.stream(self, inputs, params, **kwargs))
 
 
     async def assign_with_progress(self, inputs, params, **kwargs):
