@@ -2,6 +2,11 @@ from bergen.messages.types import ASSIGNATION_REQUEST
 from bergen.messages.base import MessageDataModel, MessageMetaExtensionsModel, MessageMetaModel, MessageModel
 from pydantic import BaseModel
 from typing import Optional
+from enum import Enum
+
+class AssignationAction(str, Enum):
+    CANCEL = 'cancel'
+    START = "start"
 
 
 class AssignationRequestParams(BaseModel):
@@ -28,6 +33,7 @@ class AssignationRequestDataModel(MessageDataModel):
     node: Optional[int] #TODO: Maybe not optional
     pod: Optional[int]
     template: Optional[int]
+    action: AssignationAction = AssignationAction.START
     reference: str
     callback: Optional[str]
     progress: Optional[str]
