@@ -325,7 +325,7 @@ class WebsocketPostman(BasePostman):
         if future.cancelled():
             request.data.action = AssignationAction.CANCEL
             self.tasks.append(asyncio.create_task(self.send_to_arnheim(request)))
-            print("hallo")
+            logger.warn(f"Cancelling Assignation {request.data.reference}")
 
 
     async def provide(self, node, params, **extensions):
